OC.L10N.register(
    "settings",
    {
    "Saved" : "Запаметяване",
    "Email sent" : "Имейлът е изпратен",
    "Valid until {date}" : "Далидна до {date}",
    "Delete" : "Изтриване",
    "Local" : "Локално",
    "Only visible to local users" : "Видима само за локални потребители",
    "Only visible to you" : "Видима само за вас",
    "Contacts" : "Контакти",
    "Visible to local users and to trusted servers" : "Видима за локални потребители и от доверени сървъри",
    "Public" : "Публичен",
    "Unable to change password" : "Неуспешна смяна на паролата.",
    "Very weak password" : "Много проста парола",
    "Weak password" : "Проста парола",
    "So-so password" : "Не особено добра парола",
    "Good password" : "Добра парола",
    "Strong password" : "Сложна парола",
    "Select a profile picture" : "Избор на снимка за профила",
    "Week starts on {fdow}" : "Първи ден от седмицата е {fdow}",
    "Groups" : "Групи",
    "{actor} changed your password" : "{actor} промени паролата ви",
    "You changed your password" : "Променихте паролата си",
    "Your password was reset by an administrator" : "Паролата ви е променена от администратора",
    "{actor} changed your email address" : "{actor} промени имейл адреса ви",
    "You changed your email address" : "Променихте имейл адреса си",
    "Your email address was changed by an administrator" : "Имейл адреса ви е променена от администратора",
    "Security" : "Сигурност",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Вашата <strong>парола</strong> или <strong>имейл адрес</strong> е променен",
    "Couldn't remove app." : "Приложението не бе премахнато.",
    "Couldn't update app." : "Приложението не бе актуализирано.",
    "Wrong password" : "Грешна парола",
    "No user supplied" : "Липсва потребител",
    "Authentication error" : "Възникна проблем с удостоверяването",
    "Wrong admin recovery password. Please check the password and try again." : "Грешна администраторска парола за възстановяване. Моля, проверете паролата и опитайте отново.",
    "Invalid SMTP password." : "Невалидна SMTP парола.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Възникна проблем при изпращането на имейла. Моля, провери настройките.  (Грешка: %s)",
    "You need to set your user email before being able to send test emails." : "Трябва да зададете своя имейл за да можете да изпращате тестови имейли.",
    "Invalid mail address" : "невалиден адрес на електронна поща",
    "Settings saved" : "Настройките са запазени",
    "Unable to change full name" : "Неуспешна промяна на име.",
    "Unable to change email address" : "Неуспешна промяна на адрес на електронна поща",
    "%1$s changed your password on %2$s." : "%1$s промени вашата парола за %2$s.",
    "Your password on %s was changed." : "Вашата парола за %s беше променена.",
    "Password changed for %s" : "Паролата на %s е променена",
    "If you did not request this, please contact an administrator." : "Моля, свържете се с администратор ако промяната не е извършена от вас.",
    "Your %s account was created" : "Вашия %s профил бе създаден",
    "Welcome aboard" : "Добре дошли",
    "Welcome aboard %s" : "Добре дошли %s",
    "Your username is: %s" : "Потребителско име: %s",
    "Set your password" : "Задайте парола",
    "Unlimited" : "Неограничено",
    "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Ползването на двустепенното удостоверяване може да бъде наложено на всички\tпотребители или определени групи. Ако потребител не е настроил втората стъпка - няма да може да се впише.",
    "Limit to groups" : "Ограничен достъп",
    "Update to {version}" : "Актуализирай до {version}",
    "Disable" : "Изключване",
    "All" : "Всички",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Приложението не може да бъде инсталирано, защото следните зависимости не са удовлетворени:",
    "View in store" : "Страница в магазина",
    "Visit website" : "Уеб страницата",
    "Report a bug" : "Докладване на грешка",
    "User documentation" : "Документация за потребители",
    "Admin documentation" : "Документация за администратори",
    "Developer documentation" : "Документация за разработчици",
    "Update to {update}" : "Актуализирай до {update}",
    "No apps found for your version" : "Няма намерени приложения за версията, която ползвате",
    "Download and enable" : "Сваляне и включване",
    "Enable" : "Включване",
    "Enable untested app" : "Включване (нетествано приложение)",
    "The app will be downloaded from the app store" : "Приложението ще бъде свалено от магазина за приложения.",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Приложението не е маркирано като съвместимо с вашата версия на Nextcloud. Можете да инсталирате приложението, но е вероятно да не работи безпроблемно.",
    "Device settings" : "Настройки за устройството",
    "Allow filesystem access" : "Разрешен достъп до файловете",
    "Revoke" : "Отнемане",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome за Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "This session" : "Текущата сесия",
    "Device" : "Устройство",
    "Last activity" : "Последна активност",
    "Devices & sessions" : "Устройства и сесии",
    "Web, desktop and mobile clients currently logged in to your account." : "Уеб, настолни и мобилни клиенти, които в момента са вписани чрез вашия акаунт.",
    "App name" : "Име на приложението",
    "Create new app password" : "Създай парола за приложението",
    "Use the credentials below to configure your app or device." : "Ползвайте данните по-долу за да настроите вашето приложение или устройство.",
    "Username" : "Потребител",
    "Password" : "Парола",
    "Done" : "Готово",
    "Copied!" : "Копирано!",
    "Copy" : "Копиране",
    "Add user in group" : "Добавяне към група",
    "Delete user" : "Изтриване",
    "Disable user" : "Деактивирай",
    "Enable user" : "Активиране",
    "Cancel" : "Отказ",
    "{size} used" : "{size} използвани",
    "Email" : "Имейл",
    "Group admin for" : "Групов администратор за",
    "Quota" : "Квота",
    "Language" : "Език",
    "Storage location" : "Дисково пространство",
    "Last login" : "Последно вписване",
    "Default language" : "Стандартен език",
    "Add a new user" : "Добавяне на новия потребител",
    "Default quota" : "Стандартна квота",
    "All languages" : "Всички езици",
    "Your apps" : "Вашите приложения",
    "Active apps" : "Включени приложения",
    "Disabled apps" : "Изключени приложения",
    "Updates" : "Актуализации",
    "New user" : "Нов потребител",
    "Default quota:" : "Стандартна квота:",
    "Select default quota" : "Изберете стандартна квота",
    "Show Languages" : "Показвай ползвания език",
    "Show last login" : "Показвай последното вписване",
    "Admins" : "Администратори",
    "Disabled users" : "Деактивирани потребители",
    "Everyone" : "Всички",
    "Add group" : "Нова група",
    "Common Name" : "Познато Име",
    "Valid until" : "Валиден до",
    "Issued By" : "Издаден от",
    "Valid until %s" : "Валиден до %s",
    "Import root certificate" : "Внасяне на основен сертификат",
    "Administrator documentation" : "Документация за администратори",
    "Documentation" : "Документация",
    "Forum" : "Форум",
    "None" : "Няма",
    "Login" : "Вписване",
    "Plain" : "Обикновен",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Имейл сървър",
    "Open documentation" : "Отвори документацията",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "След като настроите сървъра Nextcloud ще може да изпраща имейли за възстановяване на забравени пароли и известия.",
    "Send mode" : "Режим на изпращане",
    "Encryption" : "Криптиране",
    "From address" : "От адрес",
    "mail" : "поща",
    "Authentication method" : "Метод за удостоверяване",
    "Authentication required" : "Нужно е удостоверяване",
    "Server address" : "Адрес на сървъра",
    "Port" : "Порт",
    "Credentials" : "Потребител и парола",
    "SMTP Username" : "SMTP потребител",
    "SMTP Password" : "SMTP парола",
    "Test email settings" : "Проверка на имейл настройките",
    "Send email" : "Изпрати имейл",
    "Security & setup warnings" : "Предупреждения за сигурността и настройките",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Важно е, от гледна точка на сигурност и производителност, всичко да бъде настроено коректно. За тази цел са създадени автоматични проверки. Прегледайте връзките, към документацията (по-долу), за допълнителна информация.",
    "There are some errors regarding your setup." : "Открити са грешки, в инсталацията на Nextcloud.",
    "There are some warnings regarding your setup." : "Предупреждения относно текущата инсталация.",
    "Checking for system and security issues." : "Проверка за проблеми със системата и сигурността.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Прегледайте  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">ръководството за инсталиране ↗</a>, и проверете  <a href=\"%2$s\">журналите</a>за предупреждения и грешки. ",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Проверете сигурността на Nextcloud <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">като заявите сканиране ↗</a>.",
    "Version" : "Версия",
    "Two-Factor Authentication" : "Двустепенно удостоверяване",
    "Enable encryption" : "Включване на криптиране",
    "Select default encryption module:" : "Избор на модул за криптиране по подразбиране:",
    "Start migration" : "Начало на миграцията",
    "Last job ran %s." : "За последно cron задача е стартирала %s.",
    "Last job execution ran %s. Something seems wrong." : "За последно cron задача е стартирала %s. Изглежда, че има проблем.",
    "Execute one task with each page loaded" : "Изпълнява една задача с всяка заредена страница.",
    "The cron.php needs to be executed by the system user \"%s\"." : "Необходимо е cron.php да се стартира от системния потребител \"%s\".",
    "Sharing" : "Споделяне",
    "Allow apps to use the Share API" : "Разреши приложенията да използват Share API",
    "Expire after " : "Изтечи след",
    "days" : "дена",
    "Enforce expiration date" : "Изисквай дата на изтичане",
    "Allow users to share via link" : "Разреши потребителите да споделят с връзка",
    "Allow public uploads" : "Разреши общодостъпно качване",
    "Enforce password protection" : "Изискай защита с парола.",
    "Allow resharing" : "Може да споделя повторно",
    "Restrict users to only share with users in their groups" : "Ограничи потребителите, така че да могат да споделят само с други потребители в своите групи.",
    "Exclude groups from sharing" : "Забрани групи да споделят",
    "These groups will still be able to receive shares, but not to initiate them." : "Тези групи ще могат да получават споделения, но няма да могат самите те да споделят.",
    "Personal" : "Лични",
    "Administration" : "Административни",
    "Follow us on Twitter" : "Следвайте ни в Twitter",
    "Follow us on Mastodon" : "Следвайте ни в Mastodon",
    "Check out our blog" : "Посетете блога ни",
    "Subscribe to our newsletter" : "Абонирайте се за нашия имейл бюлетин",
    "Profile picture" : "Снимка за профила",
    "Upload new" : "Качи нова",
    "Select from Files" : "Избери от файловете",
    "Remove image" : "Премахни изображението",
    "png or jpg, max. 20 MB" : "png или jpg, макс. 20 MB",
    "Choose as profile picture" : "Избор на профилна снимка",
    "Details" : "Подробности",
    "You are a member of the following groups:" : "Членувате в следните групи:",
    "You are using <strong>%s</strong>" : "Ползвате <strong>%s</strong>",
    "Full name" : "Име",
    "No display name set" : "Няма настроено екранно име",
    "Your email address" : "Вашият имейл адрес",
    "No email address set" : "Не е въведен имейл адрес",
    "For password reset and notifications" : "За възстановяване на забравена парола и известия",
    "Phone number" : "Тел. номер",
    "Your phone number" : "Вашият тел. номер",
    "Address" : "Адрес",
    "Your postal address" : "Вашият пощенски код",
    "Website" : "Уеб страница",
    "Twitter" : "Twitter",
    "Help translate" : "Помогнете с превода",
    "Current password" : "Текуща парола",
    "New password" : "Нова парола",
    "Change password" : "Промени паролата",
    "Use a second factor besides your password to increase security for your account." : "Ползвайте двустепенно удостоверяване за да повишите сигурността на профила си.",
    "Not supported!" : "Не се поддържа!",
    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C.",
    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C.",
    "Afrikaans" : "африкаанс (бурски)",
    "Armenian" : "арменски",
    "English" : "английски",
    "Hungarian" : "унгарски",
    "Japanese" : "японски",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Официалните приложения са разработени от общността. ",
    "Official" : "Официално",
    "Store credentials" : "Запиши",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "Услугата webcron стартира cron.php всеки 15 минути по HTTP.",
    "Use system cron service to call the cron.php file every 15 minutes." : "Ползва услугата cron на сървъра за да стартира cron.php всеки 15 минути.",
    "Set default expiration date" : "Задайте стандартен срок на валидност",
    "Follow us on Google+" : "Следвайте ни в Google+"
},
"nplurals=2; plural=(n != 1);");
